@@ -27,8 +27,8 @@ KnowledgeDb::Coordinate WikiData::parseCoordinate(const QString& value)
     const auto idx = value.indexOf(QLatin1Char(' '));
     bool latOk = false, longOk = false;
     KnowledgeDb::Coordinate c;
-    c.longitude = value.midRef(6, idx - 6).toFloat(&latOk);
-    c.latitude = value.midRef(idx + 1, value.size() - idx - 2).toFloat(&longOk);
+    c.longitude = QStringView(value).mid(6, idx - 6).toFloat(&latOk);
+    c.latitude = QStringView(value).mid(idx + 1, value.size() - idx - 2).toFloat(&longOk);
     if (!latOk || !longOk) {
         c.longitude = NAN;
         c.latitude = NAN;
@@ -44,7 +44,7 @@ QJsonArray WikiData::query(const char *sparqlQuery, const char *cacheFileName)
 QJsonArray WikiData::query(const QString &sparqlQuery, const QString &cacheFileName)
 {
     QDir().mkdir(QStringLiteral("data"));
-    QFile cacheFile(QLatin1String("data/") + cacheFileName);
+    QFile cacheFile(QLatin1StringView("data/") + cacheFileName);
     QByteArray data;
     if (cacheFile.exists() && qEnvironmentVariableIsSet("KITINERARY_USE_WIKIDATA_CACHE")) {
         cacheFile.open(QFile::ReadOnly);
@@ -63,7 +63,7 @@ QJsonArray WikiData::query(const QString &sparqlQuery, const QString &cacheFileN
         auto reply = nam.get(QNetworkRequest(url));
         QObject::connect(reply, &QNetworkReply::finished, QCoreApplication::instance(), &QCoreApplication::quit);
         QCoreApplication::exec();
-    if (reply->error() != QNetworkReply::NoError) {
+        if (reply->error() != QNetworkReply::NoError) {
             qWarning() << reply->errorString();
             return {};
         }
@@ -74,6 +74,10 @@ QJsonArray WikiData::query(const QString &sparqlQuery, const QString &cacheFileN
     }
 
     const auto doc = QJsonDocument::fromJson(data);
-    const auto resultArray = doc.object().value(QLatin1String("results")).toObject().value(QLatin1String("bindings")).toArray();
+    const auto resultArray = doc.object()
+                                 .value(QLatin1StringView("results"))
+                                 .toObject()
+                                 .value(QLatin1String("bindings"))
+                                 .toArray();
     return resultArray;
 }
