@@ -5,8 +5,13 @@
 
 function parsePkPass(pass, node) {
     let res = node.result[0];
-    console.log(pass);
     res.reservationFor.name = pass.logoText;
+    if (!res.reservationFor.name) {
+        const eventLine = pass.field["KEY_EVENTLINE"];
+        if (eventLine) {
+            res.reservationFor.name = eventLine.value.split("\n")[0];
+        }
+    }
     const loc = pass.field['KEY_LOCATION'].value.split('\n');
     res.reservationFor.location = JsonLd.newObject('Place');
     res.reservationFor.location.name = loc[0];
